import { __decorate } from "tslib";
import { attr, customElement, FASTElement } from '@microsoft/fast-element';
import { EventName } from '../../types';
import { logger } from '../../utils';
import { DesignSystemExportStyles as styles } from './design-system-export.styles';
import { DesignSystemExportTemplate as template } from './design-system-export.template';
let DesignSystemExport = class DesignSystemExport extends FASTElement {
    constructor() {
        super(...arguments);
        this.formatValues = (detail) => {
            const space = 3;
            const designTokensConfig = {
                design_tokens: {
                    color: {
                        accent: {
                            $value: detail.accentColor,
                            $type: 'color',
                        },
                        neutral: {
                            $value: detail.neutralColor,
                            $type: 'color',
                        },
                    },
                    fontFamily: {
                        bodyFont: {
                            $value: detail.bodyFont,
                            $type: 'fontFamily',
                        },
                    },
                    typography: {
                        baseFontSize: {
                            $value: detail.baseFontSize,
                            $type: 'dimension',
                        },
                        baseLineHeight: {
                            $value: detail.baseLineHeight,
                            $type: 'dimension',
                        },
                    },
                    mode: {
                        luminance: {
                            $value: detail.luminance,
                            $type: 'number',
                        },
                    },
                    style: {
                        density: {
                            $value: detail.density,
                            $type: 'number',
                        },
                        borderRadius: {
                            $value: detail.borderRadius,
                            $type: 'number',
                        },
                        strokeWidth: {
                            $value: detail.strokeWidth,
                            $type: 'number',
                        },
                    },
                    space: {
                        designUnit: {
                            $value: detail.designUnit,
                            $type: 'number',
                        },
                    },
                },
            };
            return JSON.stringify(designTokensConfig, null, space);
        };
        this.showModal = () => {
            return this.modal.show();
        };
        this.closeModal = () => {
            return this.modal.close();
        };
        this.updateTokens = () => {
            fetch('api/tokens', {
                method: 'PUT',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({ tokens: this.value }),
            })
                .then((response) => {
                if (!response.ok) {
                    throw new Error(`API request failed with status ${response.status}`);
                }
                return response.json();
            })
                .then((data) => {
                logger.log('Tokens saved successfully:', data);
                this.$emit(EventName.APPLY_CUSTOM_DESIGN, data.message);
            })
                .catch((error) => {
                logger.error('Error saving tokens:', error);
            });
            this.closeModal();
        };
    }
    connectedCallback() {
        super.connectedCallback();
        document.body.addEventListener(EventName.STYLES_CHANGED, (event) => {
            const customEvent = event;
            this.value = this.formatValues(customEvent.detail);
        });
    }
};
__decorate([
    attr
], DesignSystemExport.prototype, "value", void 0);
__decorate([
    attr
], DesignSystemExport.prototype, "tokensPath", void 0);
DesignSystemExport = __decorate([
    customElement({
        name: 'design-system-export',
        template,
        styles,
    })
], DesignSystemExport);
export { DesignSystemExport };
